UsbSerial class abstract

Implementers

Constructors

UsbSerial()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<bool>
关闭串口
create() → dynamic
初始化
getAvailablePorts() → Future<List<String>>
获取可用串口
isOpen() → bool
串口状态
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() → Future<bool>
打开串口
readByteOnListen(dynamic onData(Uint8List value)) → void
设置读数监听
setPortParameters() → Future<void>
设置参数
toString() → String
A string representation of this object.
inherited
write(Uint8List data) → Future<void>
写入字节列表
writeString(String data) → Future<void>
写入字符串

Operators

operator ==(Object other) → bool
The equality operator.
inherited